apriltag library

A dart wrapper of apriltag library.

AprilTag is a visual fiducial system popular in robotics research.

Predefined tag families are available at apriltag-imgs.

You can generate your own tag family using apriltag-generation.

Classes

AprilTagDetectionInfo
AprilTagDetector
AprilTagFamily
AprilTagPose
This struct holds the transformation from the camera optical frame to the April tag frame. The pose refers to the position of the tag within the camera frame.
Detection
ImageU8
MatD
Defines a matrix structure for holding double-precision values with data in row-major order (i.e. index = row*ncols + col).
ZArray

Enums

FamilyType

Extensions

AprilTagPosePointerExtension on Pointer<apriltag_pose_t>
MatDPointerExtension on Pointer<matd_t>

Functions

estimatePoseForTagHomography(AprilTagDetectionInfo info) AprilTagPose
Estimate pose of the tag using the homography method described in 1. @outparam pose
estimateTagPose(AprilTagDetectionInfo info) → (double, AprilTagPose)
Estimate tag pose. This method is an easier to use interface to estimate_tag_pose_orthogonal_iteration.

Exceptions / Errors

AprilTagException